pub unsafe fn retain_command_queue(
    command_queue: cl_command_queue
) -> Result<(), cl_int>
Retain an OpenCL command-queue.
Calls clRetainCommandQueue to increment the command-queue reference count.

  • command_queue - the OpenCL command-queue.

returns an empty Result or the error code from the OpenCL C API function.

Safety

This function is unsafe because it changes the OpenCL object reference count.