enqueue_release_egl_objects

Function enqueue_release_egl_objects 

pub unsafe fn enqueue_release_egl_objects(
    command_queue: cl_command_queue,
    num_objects: cl_uint,
    mem_objects: *const cl_mem,
    num_events_in_wait_list: cl_uint,
    event_wait_list: *const cl_event,
) -> Result<cl_event, cl_int>
Release OpenCL memory objects that have been created from EGL resources. Requires the cl_khr_egl_image extension. Calls clEnqueueReleaseEGLObjectsKHR.

  • command_queue - a valid OpenCL command_queue.
  • num_objects - the number of memory objects to acquire.
  • mem_objects - the memory objects to acquire.
  • num_events_in_wait_list - the number of events in the wait list.
  • event_wait_list - the wait list events.

returns a Result containing the new OpenCL event or the error code from the OpenCL C API function.

Safety

This is unsafe because command_queue is a raw pointer.