Module info_type

Module info_type 

Enums

InfoType
A Rust enum to handle OpenCL API “Info” function return types. Each of the data types may be extracted from the enum using its associated From trait or to_* function.