Module memory

Module memory 

OpenCL Memory Object API.

Structs

cl_buffer_region
cl_image_desc
cl_image_format

Constants

CL_A
CL_ABGR
CL_ADDRESS_CLAMP
CL_ADDRESS_CLAMP_TO_EDGE
CL_ADDRESS_MIRRORED_REPEAT
CL_ADDRESS_NONE
CL_ADDRESS_REPEAT
CL_ARGB
CL_BGRA
CL_BUFFER_CREATE_TYPE_REGION
CL_DEPTH
CL_FALSE
CL_FILTER_LINEAR
CL_FILTER_NEAREST
CL_FLOAT
CL_HALF_FLOAT
CL_IMAGE_ARRAY_SIZE
CL_IMAGE_BUFFER
CL_IMAGE_DEPTH
CL_IMAGE_ELEMENT_SIZE
CL_IMAGE_FORMAT
CL_IMAGE_HEIGHT
CL_IMAGE_NUM_MIP_LEVELS
CL_IMAGE_NUM_SAMPLES
CL_IMAGE_ROW_PITCH
CL_IMAGE_SLICE_PITCH
CL_IMAGE_WIDTH
CL_INTENSITY
CL_INVALID_VALUE
CL_LUMINANCE
CL_MAP_READ
CL_MAP_WRITE
CL_MAP_WRITE_INVALIDATE_REGION
CL_MEM_ALLOC_HOST_PTR
CL_MEM_ASSOCIATED_MEMOBJECT
CL_MEM_CONTEXT
CL_MEM_COPY_HOST_PTR
CL_MEM_FLAGS
CL_MEM_HOST_NO_ACCESS
CL_MEM_HOST_PTR
CL_MEM_HOST_READ_ONLY
CL_MEM_HOST_WRITE_ONLY
CL_MEM_KERNEL_READ_AND_WRITE
CL_MEM_MAP_COUNT
CL_MEM_OBJECT_BUFFER
CL_MEM_OBJECT_IMAGE1D
CL_MEM_OBJECT_IMAGE1D_ARRAY
CL_MEM_OBJECT_IMAGE1D_BUFFER
CL_MEM_OBJECT_IMAGE2D
CL_MEM_OBJECT_IMAGE2D_ARRAY
CL_MEM_OBJECT_IMAGE3D
CL_MEM_OBJECT_PIPE
CL_MEM_OFFSET
CL_MEM_PROPERTIES
CL_MEM_READ_ONLY
CL_MEM_READ_WRITE
CL_MEM_REFERENCE_COUNT
CL_MEM_SIZE
CL_MEM_SVM_ATOMICS
CL_MEM_SVM_FINE_GRAIN_BUFFER
CL_MEM_TYPE
CL_MEM_USES_SVM_POINTER
CL_MEM_USE_HOST_PTR
CL_MEM_WRITE_ONLY
CL_MIGRATE_MEM_OBJECT_CONTENT_UNDEFINED
CL_MIGRATE_MEM_OBJECT_HOST
CL_PIPE_MAX_PACKETS
CL_PIPE_PACKET_SIZE
CL_PIPE_PROPERTIES
CL_R
CL_RA
CL_RG
CL_RGB
CL_RGBA
CL_RGBx
CL_RGx
CL_Rx
CL_SIGNED_INT8
CL_SIGNED_INT16
CL_SIGNED_INT32
CL_SNORM_INT8
CL_SNORM_INT16
CL_SUCCESS
CL_TRUE
CL_UNORM_INT8
CL_UNORM_INT16
CL_UNORM_INT_101010
CL_UNORM_INT_101010_2
CL_UNORM_SHORT_555
CL_UNORM_SHORT_565
CL_UNSIGNED_INT8
CL_UNSIGNED_INT16
CL_UNSIGNED_INT32
CL_sRGB
CL_sRGBA
CL_sRGBx

Functions

create_buffer
Create an OpenCL buffer object for a context. Calls clCreateBuffer to create an OpenCL buffer object.
create_buffer_with_properties
Create an OpenCL buffer object for a context. Calls clCreateBufferWithProperties to create an OpenCL buffer object. CL_VERSION_3_0
create_image
Create an OpenCL image object for a context. Calls clCreateImage to create an OpenCL image object.
create_image_with_properties
Create an OpenCL image object for a context. Calls clCreateImage to create an OpenCL image object. CL_VERSION_3_0
create_pipe
Create an OpenCL pipe object for a context. Calls clCreatePipe to create an OpenCL pipe object. CL_VERSION_2_0
create_sub_buffer
Create an new OpenCL buffer object from an existing buffer object. Calls clCreateSubBuffer to create an OpenCL sub-buffer object.
get_image_data
Get data about an OpenCL image object. Calls clGetImageInfo to get the desired data about the image object.
get_image_info
Get information specific to an OpenCL image object. Calls clGetImageInfo to get the desired information about the image object.
get_mem_object_data
Get data about an OpenCL memory object. Calls clGetMemObjectInfo to get the desired data about the memory object.
get_mem_object_info
Get information common to all OpenCL memory objects (buffer and image objects). Calls clGetMemObjectInfo to get the desired information about the memory objects.
get_pipe_data
Get data about an OpenCL pipe object. Calls clGetPipeInfo to get the desired data about the pipe object.
get_pipe_info
Get information specific to an OpenCL pipe object. Calls clGetPipeInfo to get the desired information about the pipe object. CL_VERSION_2_0
get_supported_image_formats
Get the list of image formats supported by an OpenCL implementation for a specified context, image type, and allocation information.
release_mem_object
Release an OpenCL memory object. Calls clReleaseMemObject to decrement the memory object reference count.
retain_mem_object
Retain an OpenCL memory object. Calls clRetainMemObject to increment the memory object reference count.
set_mem_object_destructor_callback
Register a callback function with an OpenCL memory object that is called when the memory object is destroyed. Calls clSetMemObjectDestructorCallback.
svm_alloc
Allocate a shared virtual memory (SVM) buffer that can be shared by the host and all devices in an OpenCL context. Calls clSVMAlloc. CL_VERSION_2_0
svm_free
Free a shared virtual memory (SVM) buffer allocated using clSVMAlloc. Calls clSVMFree. CL_VERSION_2_0

Type Aliases

cl_buffer_create_type
cl_context
cl_image_info
cl_int
cl_mem
cl_mem_flags
cl_mem_info
cl_mem_object_type
cl_mem_properties
cl_pipe_info
cl_svm_mem_flags
cl_uint
cl_ulong