create_image_with_properties

Function create_image_with_properties 

pub unsafe fn create_image_with_properties(
    context: cl_context,
    properties: *const cl_mem_properties,
    flags: cl_mem_flags,
    image_format: *const cl_image_format,
    image_desc: *const cl_image_desc,
    host_ptr: *mut c_void,
) -> Result<cl_mem, cl_int>
Create an OpenCL image object for a context. Calls clCreateImage to create an OpenCL image object. CL_VERSION_3_0

  • context - a valid OpenCL context.
  • properties - an optional null terminated list of properties.
  • flags - a bit-field used to specify allocation and usage information about the image memory object being created, see: Memory Flags.
  • image_format - a pointer to a structure that describes format properties of the image to be allocated.
  • image_desc - a pointer to a structure that describes type and dimensions of the image to be allocated.
  • host_ptr - a pointer to the image data that may already be allocated by the application.

returns a Result containing the new OpenCL image object or the error code from the OpenCL C API function.

Safety

This function is unsafe because incorrect flags can cause undefined behaviour.