release_mem_object

Function release_mem_object 

pub unsafe fn release_mem_object(memobj: cl_mem) -> Result<(), cl_int>
Release an OpenCL memory object. Calls clReleaseMemObject to decrement the memory object reference count.

  • memobj - the OpenCL memory object.

returns an empty Result or the error code from the OpenCL C API function.

Safety

This function is unsafe because it changes the OpenCL object reference count.