Module platform

Module platform 

OpenCL Platform API.

Structs

cl_name_version

Constants

CL_PLATFORM_EXTENSIONS
CL_PLATFORM_EXTENSIONS_WITH_VERSION
CL_PLATFORM_EXTERNAL_MEMORY_IMPORT_HANDLE_TYPES_KHR
CL_PLATFORM_HOST_TIMER_RESOLUTION
CL_PLATFORM_NAME
CL_PLATFORM_NUMERIC_VERSION
CL_PLATFORM_PROFILE
CL_PLATFORM_SEMAPHORE_EXPORT_HANDLE_TYPES_KHR
CL_PLATFORM_SEMAPHORE_IMPORT_HANDLE_TYPES_KHR
CL_PLATFORM_SEMAPHORE_TYPES_KHR
CL_PLATFORM_VENDOR
CL_PLATFORM_VERSION
CL_SUCCESS

Functions

get_platform_data
Get data about an OpenCL platform. Calls clGetPlatformInfo to get the desired data about the platform.
get_platform_ids
Get the available platforms. Calls clGetPlatformIDs to get the available platform ids.
get_platform_info
Get specific information about an OpenCL platform. Calls clGetPlatformInfo to get the desired information about the platform.

Type Aliases

cl_int
cl_platform_id
cl_platform_info
cl_uint
cl_ulong
cl_version