Module sampler

Module sampler 

OpenCL Sampler API.

Constants

CL_INVALID_VALUE
CL_SAMPLER_ADDRESSING_MODE
CL_SAMPLER_CONTEXT
CL_SAMPLER_FILTER_MODE
CL_SAMPLER_LOD_MAX
CL_SAMPLER_LOD_MIN
CL_SAMPLER_MIP_FILTER_MODE
CL_SAMPLER_NORMALIZED_COORDS
CL_SAMPLER_PROPERTIES
CL_SAMPLER_REFERENCE_COUNT
CL_SUCCESS

Functions

create_sampler
Create an OpenCL buffer sampler for a context. Calls clCreateSampler to create an OpenCL sampler object. Deprecated in CL_VERSION_2_0 by create_sampler_with_properties.
create_sampler_with_properties
Create an OpenCL buffer sampler for a context. Calls clCreateSamplerWithProperties to create an OpenCL sampler object. CL_VERSION_2_0
get_sampler_data
Get data about an OpenCL sampler object. Calls clGetDeviceInfo to get the desired data about the sampler object.
get_sampler_info
Get information specific to an OpenCL sampler object. Calls clGetImageInfo to get the desired information about the sampler object.
release_sampler
Release an OpenCL sampler. Calls clReleaseMemObject to decrement the sampler reference count.
retain_sampler
Retain an OpenCL sampler. Calls clRetainSampler to increment the sampler reference count.

Type Aliases

cl_addressing_mode
cl_bool
cl_context
cl_filter_mode
cl_int
cl_sampler
cl_sampler_info
cl_sampler_properties
cl_uint
cl_ulong