get_command_queue_info

Function get_command_queue_info 

pub fn get_command_queue_info(
    command_queue: cl_command_queue,
    param_name: cl_command_queue_info,
) -> Result<InfoType, cl_int>
Get specific information about an OpenCL command-queue. Calls clGetCommandQueueInfo to get the desired information about the command-queue.

  • command_queue - the OpenCL command-queue.
  • param_name - the type of command-queue information being queried, see: Command Queue Parameter.

returns a Result containing the desired information in an InfoType enum or the error code from the OpenCL C API function.