pub unsafe fn release_device(device: cl_device_id) -> Result<(), cl_int>Expand description
Release an OpenCL device.
Calls clReleaseDevice to decrement the device reference count
if device is a valid sub-device created by a call to clCreateSubDevices.
device- thecl_device_idof theOpenCLdevice.
returns an empty Result or the error code from the OpenCL C API function.
Safety
This function is unsafe because it changes the OpenCL object reference count.