pub unsafe fn release_mem_object(memobj: cl_mem) -> Result<(), cl_int>Expand description
Release an OpenCL memory object.
Calls clReleaseMemObject to decrement the memory object reference count.
memobj- theOpenCLmemory object.
returns an empty Result or the error code from the OpenCL C API function.
Safety
This function is unsafe because it changes the OpenCL object reference count.