OpenCL Sampler API.
Constants
- CL_
INVALID_ VALUE - CL_
SAMPLER_ ADDRESSING_ MODE - CL_
SAMPLER_ CONTEXT - CL_
SAMPLER_ FILTER_ MODE - CL_
SAMPLER_ LOD_ MAX - CL_
SAMPLER_ LOD_ MIN - CL_
SAMPLER_ MIP_ FILTER_ MODE - CL_
SAMPLER_ NORMALIZED_ COORDS - CL_
SAMPLER_ PROPERTIES - CL_
SAMPLER_ REFERENCE_ COUNT - CL_
SUCCESS
Functions
- create_
sampler - Create an
OpenCLbuffersamplerfor a context. CallsclCreateSamplerto create anOpenCLsamplerobject. Deprecated inCL_VERSION_2_0bycreate_sampler_with_properties. - create_
sampler_ with_ properties - Create an
OpenCLbuffer sampler for a context. CallsclCreateSamplerWithPropertiesto create anOpenCLsamplerobject.CL_VERSION_2_0 - get_
sampler_ data - Get data about an
OpenCLsampler object. CallsclGetDeviceInfoto get the desired data about the sampler object. - get_
sampler_ info - Get information specific to an
OpenCLsampler object. CallsclGetImageInfoto get the desired information about the sampler object. - release_
sampler ⚠ - Release an
OpenCLsampler. CallsclReleaseMemObjectto decrement thesamplerreference count. - retain_
sampler ⚠ - Retain an
OpenCLsampler. CallsclRetainSamplerto increment thesamplerreference count.